MethodChannelTencentKit class

An implementation of TencentKitPlatform that uses method channels.

Inheritance

Constructors

MethodChannelTencentKit()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isQQInstalled() → Future<bool>
检查QQ是否已安装
override
isTIMInstalled() → Future<bool>
检查QQ是否已安装
override
login({required List<String> scope, bool qrcode = false}) → Future<void>
登录
override
loginServerSide({required List<String> scope, bool qrcode = false}) → Future<void>
登录(Server-Side)
override
logout() → Future<void>
登出
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerApp({required String appId, String? universalLink}) → Future<void>
向 Open_SDK 注册
override
respStream() → Stream<TencentResp>
override
setIsPermissionGranted({required bool granted, String? buildModel}) → Future<void>
设置是否已授权获取设备信息/是否同意隐私协议
override
shareImage({required int scene, required Uri imageUri, String? appName, int extInt = TencentQZoneFlag.kDefault}) → Future<void>
分享 - 图片
override
shareMood({required int scene, String? summary, List<Uri>? imageUris, Uri? videoUri}) → Future<void>
分享 - 说说
override
shareMusic({required int scene, required String title, String? summary, Uri? imageUri, required String musicUrl, required String targetUrl, String? appName, int extInt = TencentQZoneFlag.kDefault}) → Future<void>
分享 - 音乐
override
shareText({required int scene, required String summary}) → Future<void>
分享 - 文本(Android调用的是系统API,故而不会有回调)
override
shareWebpage({required int scene, required String title, String? summary, Uri? imageUri, required String targetUrl, String? appName, int extInt = TencentQZoneFlag.kDefault}) → Future<void>
分享 - 网页
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited